@@ -47,9 +47,9 @@ def django_db_modify_db_settings_xdist_suffix(request):
 
         if not test_name:
             if db_settings["ENGINE"] == "django.db.backends.sqlite3":
-                return ":memory:"
-            else:
-                test_name = "test_{}".format(db_settings["NAME"])
+                continue
+
+            test_name = "test_{}".format(db_settings["NAME"])
 
         # Put a suffix like _gw0, _gw1 etc on xdist processes
         xdist_suffix = getattr(request.config, "slaveinput", {}).get("slaveid")
@@ -364,7 +364,7 @@ def live_server(request):
                 warnings.warn(
                     "Specifying multiple live server ports is not supported "
                     "in Django 1.11. This will be an error in a future "
-                    "pytest-django release.",
+                    "pytest-django release."
                 )
 
     if not addr:
